==> kdevplatform-0.9.84.tar.bz2: kdevplatform-0.9.84/shell/tests/shelldocumentoperationtest.h <==
/***************************************************************************
 *   Copyright 2008 Alexander Dymo <adymo@kdevelop.org>                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef SHELLDOCUMENTOPERATIONTEST_H
#define SHELLDOCUMENTOPERATIONTEST_H

#include <QObject>
#include <tests/common/autotestshell.h>

using namespace KDevelop;

class ShellDocumentOperationTest: public QObject {
    Q_OBJECT
private slots:
    void init();
    void cleanup();

    void testOpenDocumentFromText();
    void testClosing();
    void testKateDocumentAndViewCreation();

};

#endif

==> kdevplatform-0.9.99.tar.bz2: kdevplatform-0.9.99/shell/tests/shelldocumentoperationtest.h <==
/***************************************************************************
 *   Copyright 2008 Alexander Dymo <adymo@kdevelop.org>                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef SHELLDOCUMENTOPERATIONTEST_H
#define SHELLDOCUMENTOPERATIONTEST_H

#include <QObject>
#include <tests/autotestshell.h>

using namespace KDevelop;

class ShellDocumentOperationTest: public QObject {
    Q_OBJECT
private slots:
    void init();
    void cleanup();

    void testOpenDocumentFromText();
    void testClosing();
    void testKateDocumentAndViewCreation();

};

#endif
